Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3355)

Unified Diff: chrome/browser/profiles/profile_impl.cc

Issue 2945023002: Introduce profile for lock screen apps (Closed)
Patch Set: rebase Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/profiles/profile_impl.cc
diff --git a/chrome/browser/profiles/profile_impl.cc b/chrome/browser/profiles/profile_impl.cc
index 2792fe5149f08cc188a38029bb12b8fc41f09987..a3d038dc6a47e6c95f888bc7a5e0a06abd6db162 100644
--- a/chrome/browser/profiles/profile_impl.cc
+++ b/chrome/browser/profiles/profile_impl.cc
@@ -436,11 +436,12 @@ ProfileImpl::ProfileImpl(
"profile files to the root directory!";
#if defined(OS_CHROMEOS)
- if (!chromeos::ProfileHelper::IsSigninProfile(this)) {
+ if (!chromeos::ProfileHelper::IsSigninProfile(this) &&
+ !chromeos::ProfileHelper::IsLockScreenAppProfile(this)) {
const user_manager::User* user =
chromeos::ProfileHelper::Get()->GetUserByProfile(this);
// A |User| instance should always exist for a profile which is not the
// initial or the sign-in profile.
CHECK(user);
LOG_IF(FATAL,
!session_manager::SessionManager::Get()->HasSessionForAccountId(
@@ -694,7 +695,8 @@ void ProfileImpl::DoFinalInit() {
// mark the session as initialized. Need to do this before we restart below
// so we don't get in a weird state where we restart before the session is
// marked as initialized and so try to initialize it again.
- if (!chromeos::ProfileHelper::IsSigninProfile(this)) {
+ if (!chromeos::ProfileHelper::IsSigninProfile(this) &&
+ !chromeos::ProfileHelper::IsLockScreenAppProfile(this)) {
chromeos::ProfileHelper* profile_helper = chromeos::ProfileHelper::Get();
user_manager::UserManager::Get()->OnProfileInitialized(
profile_helper->GetUserByProfile(this));
@@ -436,11 +436,12 @@ ProfileImpl::ProfileImpl(
chromeos::ProfileHelper::Get()->GetUserByProfile(this);
// A |User| instance should always exist for a profile which is not the
- // initial or the sign-in profile.
+ // initial, the sign-in or the lock screen app profile.
CHECK(user);
LOG_IF(FATAL,
« no previous file with comments | « chrome/browser/policy/profile_policy_connector_factory.cc ('k') | chrome/browser/profiles/profile_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698